@@ -23,7 +23,6 @@
 #include <KIO/OpenUrlJob>
 #include <KIO/JobUiDelegate>
 #include <KGuiItem>
-#include <KIconLoader>
 #include <kio_version.h>
 #include <KIO/StatJob>
 #include <KIO/CopyJob>
@@ -239,7 +238,6 @@ HighscoresDialog::HighscoresDialog(int rank, QWidget *parent)
         KPageWidgetItem *pageItem = new KPageWidgetItem( hsw, title);
         const int iconSize = style()->pixelMetric(QStyle::PM_ToolBarIconSize);
         pageItem->setIcon(QIcon::fromTheme(icon).pixmap(iconSize));
-//         pageItem->setIcon( QIcon( BarIcon(icon, KIconLoader::SizeLarge) ) );
         addPage( pageItem );
         _pages.append(pageItem);
         connect(hsw, &HighscoresWidget::tabChanged, this, &HighscoresDialog::tabChanged);
@@ -282,11 +280,7 @@ void HighscoresDialog::slotUser2()
 //   kDebug(11001) ;
     QUrl url = QFileDialog::getSaveFileUrl(this, tr("HighscoresDialog"), QUrl(), QString());
     if ( url.isEmpty() ) return;
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 69, 0)
     auto job = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatNoDetails);
-#else
-    auto job = KIO::stat(url, KIO::StatJob::SourceSide, 0);
-#endif
     KJobWidgets::setWindow(job, this);
     job->exec();
     if (!job->error()) {
